@@ -24,40 +24,37 @@
 
 #include <QRegExp>
 
-namespace MailCommon
-{
-
+namespace MailCommon {
 //=============================================================================
 // FilterActionRewriteHeader - rewrite header
 // Rewrite a header using a regexp.
 //=============================================================================
-class FilterActionRewriteHeader: public FilterActionWithStringList
+class FilterActionRewriteHeader : public FilterActionWithStringList
 {
     Q_OBJECT
 public:
     explicit FilterActionRewriteHeader(QObject *parent = nullptr);
-    ReturnCode process(ItemContext &context, bool applyOnOutbound) const Q_DECL_OVERRIDE;
-    SearchRule::RequiredPart requiredPart() const Q_DECL_OVERRIDE;
-    QWidget *createParamWidget(QWidget *parent) const Q_DECL_OVERRIDE;
-    void setParamWidgetValue(QWidget *paramWidget) const Q_DECL_OVERRIDE;
-    void applyParamWidgetValue(QWidget *paramWidget) Q_DECL_OVERRIDE;
-    void clearParamWidget(QWidget *paramWidget) const Q_DECL_OVERRIDE;
+    Q_REQUIRED_RESULT ReturnCode process(ItemContext &context, bool applyOnOutbound) const override;
+    Q_REQUIRED_RESULT SearchRule::RequiredPart requiredPart() const override;
+    Q_REQUIRED_RESULT QWidget *createParamWidget(QWidget *parent) const override;
+    void setParamWidgetValue(QWidget *paramWidget) const override;
+    void applyParamWidgetValue(QWidget *paramWidget) override;
+    void clearParamWidget(QWidget *paramWidget) const override;
 
-    QString argsAsString() const Q_DECL_OVERRIDE;
-    void argsFromString(const QString &argsStr) Q_DECL_OVERRIDE;
+    Q_REQUIRED_RESULT QString argsAsString() const override;
+    void argsFromString(const QString &argsStr) override;
 
-    QString displayString() const Q_DECL_OVERRIDE;
+    Q_REQUIRED_RESULT QString displayString() const override;
 
     static FilterAction *newAction();
 
-    bool isEmpty() const Q_DECL_OVERRIDE;
-    QString informationAboutNotValidAction() const Q_DECL_OVERRIDE;
+    Q_REQUIRED_RESULT bool isEmpty() const override;
+    Q_REQUIRED_RESULT QString informationAboutNotValidAction() const override;
 
 private:
     QRegExp mRegExp;
     QString mReplacementString;
 };
-
 }
 
 #endif
