@@ -23,11 +23,12 @@
 #include "filter/filteractions/filteractiondict.h"
 #include "filter/filtermanager.h"
 #include "filter/mailfilter.h"
-#include <PimCommon/MinimumComboBox>
 
 #include <KLocalizedString>
 #include <QPushButton>
 #include <QIcon>
+#include <QComboBox>
+#include <QVector>
 
 #include <QGridLayout>
 #include <QLabel>
@@ -66,7 +67,7 @@ public:
 
     FilterActionWidget *q;
     QList<MailCommon::FilterAction *> mActionList;
-    KComboBox *mComboBox = nullptr;
+    QComboBox *mComboBox = nullptr;
     QPushButton *mAdd = nullptr;
     QPushButton *mRemove = nullptr;
 
@@ -117,7 +118,8 @@ FilterActionWidget::FilterActionWidget(QWidget *parent)
     d->mLayout = new QGridLayout(widget);
     d->mLayout->setContentsMargins(0, 0, 0, 0);
 
-    d->mComboBox = new PimCommon::MinimumComboBox(widget);
+    d->mComboBox = new QComboBox(widget);
+    d->mComboBox->setMinimumWidth(50);
     d->mComboBox->setEditable(false);
     Q_ASSERT(d->mComboBox);
     d->mLayout->addWidget(d->mComboBox, 1, 1);
@@ -132,9 +134,9 @@ FilterActionWidget::FilterActionWidget(QWidget *parent)
     mainLayout->setSpacing(4);
 
     int index;
-    QList<FilterActionDesc *> list = MailCommon::FilterManager::filterActionDict()->list();
-    QList<FilterActionDesc *>::const_iterator it;
-    QList<FilterActionDesc *>::const_iterator end(list.constEnd());
+    QVector<FilterActionDesc *> list = MailCommon::FilterManager::filterActionDict()->list();
+    QVector<FilterActionDesc *>::const_iterator it;
+    QVector<FilterActionDesc *>::const_iterator end(list.constEnd());
     for (index = 0, it = list.constBegin(); it != end; ++it, ++index) {
         //create an instance:
         FilterAction *action = (*it)->create();
@@ -169,12 +171,12 @@ FilterActionWidget::FilterActionWidget(QWidget *parent)
     setFocusProxy(d->mComboBox);
 
     // now connect the combo box and the widget stack
-    connect(d->mComboBox, QOverload<int>::of(&KComboBox::activated),
+    connect(d->mComboBox, QOverload<int>::of(&QComboBox::activated),
             this, [this](int index) {
         d->slotFilterTypeChanged(index);
     });
 
-    connect(d->mComboBox, QOverload<int>::of(&KComboBox::activated), this, &FilterActionWidget::filterModified);
+    connect(d->mComboBox, QOverload<int>::of(&QComboBox::activated), this, &FilterActionWidget::filterModified);
 
     connect(d->mAdd, &QPushButton::clicked,
             this, [this]() {
@@ -272,7 +274,7 @@ public:
     void regenerateActionListFromWidgets();
 
     FilterActionWidgetLister *q;
-    QList<MailCommon::FilterAction *> *mActionList = nullptr;
+    QVector<MailCommon::FilterAction *> *mActionList = nullptr;
 };
 
 void FilterActionWidgetLister::Private::regenerateActionListFromWidgets()
@@ -304,7 +306,7 @@ FilterActionWidgetLister::~FilterActionWidgetLister()
     delete d;
 }
 
-void FilterActionWidgetLister::setActionList(QList<FilterAction *> *list)
+void FilterActionWidgetLister::setActionList(QVector<FilterAction *> *list)
 {
     Q_ASSERT(list);
     if (d->mActionList && d->mActionList != list) {
@@ -341,10 +343,10 @@ void FilterActionWidgetLister::setActionList(QList<FilterAction *> *list)
 
     // load the actions into the widgets
     QList<QWidget *> widgetList = widgets();
-    QList<FilterAction *>::const_iterator aEnd(d->mActionList->constEnd());
+    QVector<FilterAction *>::const_iterator aEnd(d->mActionList->constEnd());
     QList<QWidget *>::ConstIterator wIt = widgetList.constBegin();
     QList<QWidget *>::ConstIterator wEnd = widgetList.constEnd();
-    for (QList<FilterAction *>::const_iterator aIt = d->mActionList->constBegin();
+    for (QVector<FilterAction *>::const_iterator aIt = d->mActionList->constBegin();
          (aIt != aEnd && wIt != wEnd); ++aIt, ++wIt) {
         connectWidget((*wIt), (*aIt));
     }
