@@ -718,7 +718,7 @@ void KMFilterDialog::importFilters(MailCommon::FilterImporterExporter::FilterTyp
     MailCommon::FilterImporterPathCache::self()->clear();
     FilterImporterExporter importer(this);
     bool canceled = false;
-    QList<MailFilter *> filters = importer.importFilters(canceled, type);
+    QVector<MailFilter *> filters = importer.importFilters(canceled, type);
     if (canceled) {
         return;
     }
@@ -728,9 +728,9 @@ void KMFilterDialog::importFilters(MailCommon::FilterImporterExporter::FilterTyp
         return;
     }
     QStringList listOfFilter;
-    QList<MailFilter *>::ConstIterator end(filters.constEnd());
+    QVector<MailFilter *>::ConstIterator end(filters.constEnd());
 
-    for (QList<MailFilter *>::ConstIterator it = filters.constBegin(); it != end; ++it) {
+    for (QVector<MailFilter *>::ConstIterator it = filters.constBegin(); it != end; ++it) {
         mFilterList->appendFilter(*it);   // no need to deep copy, ownership passes to the list
         listOfFilter << (*it)->name();
     }
@@ -744,7 +744,7 @@ void KMFilterDialog::importFilters(MailCommon::FilterImporterExporter::FilterTyp
 void KMFilterDialog::slotExportFilters()
 {
     bool wasCanceled = false;
-    const QList<MailFilter *> filters = mFilterList->filtersForSaving(false, wasCanceled);
+    const QVector<MailFilter *> filters = mFilterList->filtersForSaving(false, wasCanceled);
     if (filters.isEmpty()) {
         KMessageBox::information(
             this,
@@ -785,7 +785,7 @@ void KMFilterDialog::slotExportAsSieveScript()
     }
     KMessageBox::information(this, i18n("We cannot convert all KMail filters to sieve scripts but we can try :)"), i18n("Convert KMail filters to sieve scripts"));
     bool wasCanceled = false;
-    const QList<MailFilter *> filters = mFilterList->filtersForSaving(false, wasCanceled);
+    const QVector<MailFilter *> filters = mFilterList->filtersForSaving(false, wasCanceled);
     if (filters.isEmpty()) {
         return;
     }
@@ -793,7 +793,7 @@ void KMFilterDialog::slotExportAsSieveScript()
         QPointer<FilterSelectionDialog> dlg = new FilterSelectionDialog(this);
         dlg->setFilters(filters);
         if (dlg->exec() == QDialog::Accepted) {
-            QList<MailFilter *> lst = dlg->selectedFilters();
+            QVector<MailFilter *> lst = dlg->selectedFilters();
             if (!lst.isEmpty()) {
                 FilterConvertToSieve convert(lst);
                 convert.convert();
