@@ -89,7 +89,7 @@ MailFilter::MailFilter(const MailFilter &aFilter)
     mIcon = aFilter.icon();
     mShortcut = aFilter.shortcut();
 
-    QListIterator<FilterAction *> it(aFilter.mActions);
+    QVectorIterator<FilterAction *> it(aFilter.mActions);
     while (it.hasNext()) {
         FilterAction *action = it.next();
         FilterActionDesc *desc = FilterManager::filterActionDict()->value(action->name());
@@ -139,8 +139,8 @@ MailFilter::ReturnCode MailFilter::execActions(ItemContext &context, bool &stopI
 {
     ReturnCode status = NoResult;
 
-    QList<FilterAction *>::const_iterator it(mActions.constBegin());
-    QList<FilterAction *>::const_iterator end(mActions.constEnd());
+    QVector<FilterAction *>::const_iterator it(mActions.constBegin());
+    QVector<FilterAction *>::const_iterator end(mActions.constEnd());
     for (; it != end; ++it) {
         if (FilterLog::instance()->isLogging()) {
             const QString logText(i18n("<b>Applying filter action:</b> %1",
@@ -180,12 +180,12 @@ MailFilter::ReturnCode MailFilter::execActions(ItemContext &context, bool &stopI
     return status;
 }
 
-QList<FilterAction *> *MailFilter::actions()
+QVector<FilterAction *> *MailFilter::actions()
 {
     return &mActions;
 }
 
-const QList<FilterAction *> *MailFilter::actions() const
+const QVector<FilterAction *> *MailFilter::actions() const
 {
     return &mActions;
 }
@@ -277,7 +277,7 @@ SearchRule::RequiredPart MailFilter::requiredPart(const QString &id) const
 
     int requiredPartByActions = SearchRule::Envelope;
 
-    QList<FilterAction *> actionList = *actions();
+    QVector<FilterAction *> actionList = *actions();
     if (!actionList.isEmpty()) {
         requiredPartByActions = (*std::max_element(actionList.constBegin(), actionList.constEnd(),
                                                    boost::bind(&MailCommon::FilterAction::requiredPart, _1)
@@ -295,7 +295,7 @@ void MailFilter::agentRemoved(const QString &identifier)
 
 void MailFilter::folderRemoved(const Akonadi::Collection &aFolder, const Akonadi::Collection &aNewFolder)
 {
-    QListIterator<FilterAction *> it(mActions);
+    QVectorIterator<FilterAction *> it(mActions);
     while (it.hasNext()) {
         it.next()->folderRemoved(aFolder, aNewFolder);
     }
@@ -505,8 +505,8 @@ void MailFilter::generateSieveScript(QStringList &requiresModules, QString &code
 {
     mPattern.generateSieveScript(requiresModules, code);
 
-    QList<FilterAction *>::const_iterator it;
-    QList<FilterAction *>::const_iterator end(mActions.constEnd());
+    QVector<FilterAction *>::const_iterator it;
+    QVector<FilterAction *>::const_iterator end(mActions.constEnd());
 
     const QString indentationStr{
         QStringLiteral("    ")
@@ -573,8 +573,8 @@ void MailFilter::writeConfig(KConfigGroup &config, bool exportFilter) const
     QString key;
     int i;
 
-    QList<FilterAction *>::const_iterator it;
-    QList<FilterAction *>::const_iterator end(mActions.constEnd());
+    QVector<FilterAction *>::const_iterator it;
+    QVector<FilterAction *>::const_iterator end(mActions.constEnd());
 
     for (i = 0, it = mActions.constBegin(); it != end; ++it, ++i) {
         config.writeEntry(key.sprintf("action-name-%d", i),
@@ -598,7 +598,7 @@ QString MailFilter::purify(bool removeAction)
         }
         informationAboutNotValidAction += i18n("Any action defined.");
     } else {
-        QListIterator<FilterAction *> it(mActions);
+        QVectorIterator<FilterAction *> it(mActions);
         it.toBack();
         while (it.hasPrevious()) {
             FilterAction *action = it.previous();
@@ -652,8 +652,8 @@ const QString MailFilter::asString() const
 
     result += QString("Filter is %1\n").arg(bEnabled ? QStringLiteral("enabled") : QStringLiteral("disabled"));
 
-    QList<FilterAction *>::const_iterator it(mActions.constBegin());
-    QList<FilterAction *>::const_iterator end(mActions.constEnd());
+    QVector<FilterAction *>::const_iterator it(mActions.constBegin());
+    QVector<FilterAction *>::const_iterator end(mActions.constEnd());
     for (; it != end; ++it) {
         result += QStringLiteral("    action: ");
         result += (*it)->label();
@@ -708,7 +708,7 @@ QDataStream &MailCommon::operator<<(QDataStream &stream, const MailCommon::MailF
     stream << filter.mPattern.serialize();
 
     stream << filter.mActions.count();
-    QListIterator<FilterAction *> it(filter.mActions);
+    QVectorIterator<FilterAction *> it(filter.mActions);
     while (it.hasNext()) {
         const FilterAction *action = it.next();
         stream << action->name();
