@@ -24,10 +24,11 @@
 #include <KLineEdit>
 #include <QIcon>
 #include <QUrl>
-#include <QMediaPlayer>
 
 #include <QHBoxLayout>
 #include <QPushButton>
+
+#include <phonon/mediaobject.h>
 #include <QStandardPaths>
 
 using namespace MailCommon;
@@ -112,15 +113,9 @@ void SoundTestWidget::playSound()
     const QString play = (parameter.startsWith(file)
                           ? parameter.mid(file.length())
                           : parameter);
-    QMediaPlayer *player = new QMediaPlayer;
-    player->setMedia(QUrl::fromLocalFile(play));
-    player->setVolume(50);
-    connect(player, &QMediaPlayer::stateChanged, this, [this, player](QMediaPlayer::State state) {
-        if (state == QMediaPlayer::StoppedState) {
-            player->deleteLater();
-        }
-    });
+    Phonon::MediaObject *player = Phonon::createPlayer(Phonon::NotificationCategory, QUrl::fromLocalFile(play));
     player->play();
+    connect(player, &Phonon::MediaObject::finished, player, &Phonon::MediaObject::deleteLater);
 }
 
 QString SoundTestWidget::url() const
