@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2009-2018 Laurent Montel <montel@kde.org>
+  Copyright (c) 2009-2019 Laurent Montel <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -32,21 +32,51 @@
 
 #include <KColorScheme>
 #include <KLocalizedString>
+#include <collectionquotaattribute.h>
 
 #include <QPalette>
+#include <QIcon>
 
 namespace MailCommon {
 class FolderTreeWidgetProxyModel::Private
 {
 public:
-    Private()
+    Private(FolderTreeWidgetProxyModel *qq)
+        : q(qq)
     {
     }
 
+    bool checkQuotaExcedded(const QModelIndex &index, qreal &percentage)
+    {
+        if (index.model()->hasChildren(index)) {
+            const int rowCount = index.model()->rowCount(index);
+            for (int row = 0; row < rowCount; row++) {
+                const QModelIndex firstIndex = q->mapToSource(index.model()->index(row, 0, index));
+
+                const Akonadi::Collection collectionFirst
+                    = q->sourceModel()->data(
+                          firstIndex, Akonadi::EntityTreeModel::CollectionRole).value<Akonadi::Collection>();
+                if (collectionFirst.isValid() && collectionFirst.hasAttribute<Akonadi::CollectionQuotaAttribute>()) {
+                    const Akonadi::CollectionQuotaAttribute *quota = collectionFirst.attribute<Akonadi::CollectionQuotaAttribute>();
+
+                    if (quota->currentValue() > -1 && quota->maximumValue() > 0) {
+                        percentage = (100.0 * quota->currentValue()) / quota->maximumValue();
+                        if (percentage >= threshold) {
+                            return true;
+                        }
+                    }
+                }
+            }
+        }
+        return false;
+    }
+
     QSet<QString> includedMimeTypes;
     Akonadi::MimeTypeChecker checker;
 
     QColor brokenAccountColor;
+    qreal threshold = 0.0;
+    FolderTreeWidgetProxyModel *q;
     bool enableCheck = false;
     bool hideVirtualFolder = false;
     bool hideSpecificFolder = false;
@@ -55,7 +85,7 @@ public:
 
 FolderTreeWidgetProxyModel::FolderTreeWidgetProxyModel(QObject *parent, FolderTreeWidgetProxyModelOptions option)
     : Akonadi::EntityRightsFilterModel(parent)
-    , d(new Private)
+    , d(new Private(this))
 {
     setDynamicSortFilter(true);
     setFilterCaseSensitivity(Qt::CaseInsensitive);
@@ -77,6 +107,11 @@ FolderTreeWidgetProxyModel::~FolderTreeWidgetProxyModel()
     delete d;
 }
 
+void FolderTreeWidgetProxyModel::setWarningThreshold(qreal threshold)
+{
+    d->threshold = threshold;
+}
+
 void FolderTreeWidgetProxyModel::readConfig()
 {
     invalidate();
@@ -191,7 +226,7 @@ bool FolderTreeWidgetProxyModel::acceptRow(int sourceRow, const QModelIndex &sou
 
 QVariant FolderTreeWidgetProxyModel::data(const QModelIndex &index, int role) const
 {
-    if (role == Qt::TextColorRole) {
+    if (role == Qt::ForegroundRole) {
         const QModelIndex sourceIndex = mapToSource(index);
         const QModelIndex rowIndex = sourceIndex.sibling(sourceIndex.row(), 0);
         const Akonadi::Collection collection
@@ -223,6 +258,24 @@ QVariant FolderTreeWidgetProxyModel::data(const QModelIndex &index, int role) co
                 if (!instance.isOnline()) {
                     return i18n("%1 (Offline)", Akonadi::EntityRightsFilterModel::data(index, role).toString());
                 }
+                qreal percentage = 0.0;
+                if (d->checkQuotaExcedded(index, percentage)) {
+                    return i18n("%1 (Reached %2% quota)", Akonadi::EntityRightsFilterModel::data(index, role).toString(), static_cast<int>(percentage));
+                }
+            }
+        }
+    } else if (role == Qt::DecorationRole) {
+        const QModelIndex sourceIndex = mapToSource(index);
+        const QModelIndex rowIndex = sourceIndex.sibling(sourceIndex.row(), 0);
+        const Akonadi::Collection collection
+            = sourceModel()->data(
+                  rowIndex, Akonadi::EntityTreeModel::CollectionRole).value<Akonadi::Collection>();
+        if (!MailCommon::Util::isVirtualCollection(collection)) {
+            if (collection.parentCollection() == Akonadi::Collection::root()) {
+                qreal percentage = 0.0;
+                if (d->checkQuotaExcedded(index, percentage)) {
+                    return QIcon::fromTheme(QStringLiteral("emblem-warning"));
+                }
             }
         }
     }
